@@ -113,7 +113,6 @@ RPC2_EncryptionKey TokenKey;	/* Used for encrypting server tokens;
 				    modified by SetKeys() routine; changed periodically  */
 int TokenTime = 0;	/* last modified time on TokenKey file	*/
 static char *Auth2TKFile = NULL;	/* name of token key file */
-static int AUTime = 0;			/* used to tell if binaries have changed */
 
 static int CheckOnly = 0;	/* only allow password checking at this server */
 static int DoRedirectLog = 1;	/* set to zero by -r switch on command line */
@@ -222,7 +221,6 @@ static void InitGlobals(int argc, char **argv)
 {
     register int i;
     int	len;
-    struct stat buff;
 
     len = strlen(argv[0]);
     for (i=0; i<len; i++)
@@ -287,8 +285,6 @@ static void InitGlobals(int argc, char **argv)
     }    
 
     CheckTokenKey();
-
-    AUTime = buff.st_mtime;
 }
 
 
@@ -581,7 +577,7 @@ long S_AuthGetTokens(RPC2_Handle cid, EncryptedSecretToken est, ClearToken *cTok
     sToken.Noise4 = rpc2_NextRandom(NULL);
     hton_SecretToken(&sToken);
     CheckTokenKey();
-    rpc2_Encrypt((char *)&sToken, (char *)est, sizeof(SecretToken), (char *)TokenKey, RPC2_XOR);
+    rpc2_Encrypt((char *)&sToken, (char *)est, sizeof(SecretToken), TokenKey, RPC2_XOR);
 
     return(0);
     }
@@ -596,15 +592,14 @@ long S_AuthChangePasswd (RPC2_Handle cid, RPC2_Integer viceId,
     int len;
 
     memset(newPasswd, 0, sizeof(newPasswd));
-    if (strlen(Passwd) < RPC2_KEYSIZE) 
-	    len = strlen(Passwd);
-    else
-	    len = RPC2_KEYSIZE;
+    len = strlen((char *)Passwd);
+    if (len > RPC2_KEYSIZE) 
+	len = RPC2_KEYSIZE;
     memcpy(newPasswd, Passwd, len); 
 
     if (AuthDebugLevel)
 	{
-	printf("AuthChangePasswd(%ld, \"", viceId);
+	printf("AuthChangePasswd(%d, \"", viceId);
 	for (i = 0; i < RPC2_KEYSIZE; i++)
 	    printf("%c", newPasswd[i]);
 	printf("\")");
