@@ -122,7 +122,7 @@ long PWGetKeys(RPC2_CountedBS *cIdent, RPC2_EncryptionKey hKey, RPC2_EncryptionK
 		LogMsg(0, AuthDebugLevel, stdout, "Problem statting auth2.pw");
 
 	memcpy(hKey, PWArray[vid], RPC2_KEYSIZE);
-	rpc2_Decrypt((char *)hKey, (char *)hKey, RPC2_KEYSIZE, (unsigned char *)FileKey, RPC2_XOR);
+	rpc2_Decrypt((char *)hKey, (char *)hKey, RPC2_KEYSIZE, FileKey, RPC2_XOR);
 	for (i=0; i < RPC2_KEYSIZE; i++)
 		sKey[i] = rpc2_NextRandom(NULL);	/* random session key */
 
@@ -264,11 +264,10 @@ void AppendPW(int vId, RPC2_EncryptionKey eKey, char *otherInfo, int agentId)
 	char buf[100], *bnext;
 	RPC2_EncryptionKey tempkey;
 	struct stat buff;
-	long cl;
+	time_t cl;
 
 	/* Encrypt the key first */
-	rpc2_Encrypt((char *)eKey, (char *)tempkey, RPC2_KEYSIZE,
-		(char *)FileKey, RPC2_XOR);
+	rpc2_Encrypt((char *)eKey, (char *)tempkey, RPC2_KEYSIZE, FileKey, RPC2_XOR);
 
 	/* Update PWArray after enlarging it */
 	if (vId >= PWLen) EnlargePW(2*vId);
@@ -379,7 +378,7 @@ long PWChangeUser(RPC2_Handle cid, RPC2_Integer viceId, RPC2_EncryptionKey newKe
 
 	if (AuthDebugLevel)
 	{
-		printf("AuthChangeUser(%ld, \"", viceId);
+		printf("AuthChangeUser(%d, \"", viceId);
 		for (i = 0; i < RPC2_KEYSIZE; i++)
 			printf("%c", newKey[i]);
 		printf("\", \"%s\")\n", (char *)otherInfo);
@@ -428,7 +427,7 @@ long PWChangePasswd(RPC2_Handle cid, RPC2_Integer viceId, RPC2_String Passwd)
 
 	if (AuthDebugLevel)
 	{
-		printf("AuthChangePasswd(%ld, \"", viceId);
+		printf("AuthChangePasswd(%d, \"", viceId);
 		for (i = 0; i < RPC2_KEYSIZE; i++)
 			printf("%c", newPasswd[i]);
 		printf("\")");
@@ -488,7 +487,7 @@ int IsAdministrator(struct UserInfo *pU)
 int BogusKey(RPC2_EncryptionKey x)
 {
 	RPC2_EncryptionKey temp;
-	rpc2_Encrypt((char *)x, (char *)temp, RPC2_KEYSIZE, (char *)FileKey, RPC2_XOR);
+	rpc2_Encrypt((char *)x, (char *)temp, RPC2_KEYSIZE, FileKey, RPC2_XOR);
 	if (memcmp(temp, NullKey, RPC2_KEYSIZE) == 0) return(TRUE);
 	if (memcmp(temp, DeleteKey, RPC2_KEYSIZE) == 0) return(TRUE);
 	return(FALSE);
