@@ -13,19 +13,15 @@ listed in the file CREDITS.
 
                         Additional copyrights
                            none currently
-
 #*/
 
-
-
-
-
-
-
 /* cure.h */
+#include <vcrcommon.h>
 
 /* routines included in other files */
 int ObjExists (resreplica *, long , long );
-int RepairRename (int , resreplica *, resdir_entry **, int , listhdr **, char *, VolumeId, char *realm);
-int RepairSubsetCreate (int , resreplica *, resdir_entry **, int , listhdr **, VolumeId);
+int RepairRename (int , resreplica *, resdir_entry **, int, listhdr **,
+		  char *, VolumeId, char *realm);
+int RepairSubsetCreate (int , resreplica *, resdir_entry **, int , listhdr **,
+			VolumeId);
 int RepairSubsetRemove (int, resreplica *, resdir_entry **, int , listhdr **);
