@@ -209,15 +209,16 @@ static void Connect()
     RPC2_CountedBS cident;
     RPC2_EncryptionKey secret;
     char hostname[64];
-    long portmapid;
-    long port;
+    RPC2_Integer portmapid;
+    RPC2_Integer port;
 
     portmapid = portmap_bind(host);
     if ( !portmapid ) {
 	    fprintf(stderr, "Cannot bind to rpc2portmap; exiting\n");
 	    exit(1);
     }
-    rc = portmapper_client_lookup_pbynvp(portmapid, (unsigned char *)"codaupdate", 0, 17, &port);
+    rc = portmapper_client_lookup_pbynvp(portmapid, (RPC2_String)"codaupdate",
+					 0, 17, &port);
 
     RPC2_Unbind(portmapid);
     if ( rc ) {
