@@ -187,10 +187,6 @@ class fsdb {
     /*T*/char matriculation_sync;
     /*T*/int matriculation_count;
 
-    /* Device handle for opening files by <dev,ino> rather than name. */
-     int damnit;
-    /*T*/dev_t device;
-
     /* Constructors, destructors. */
     void *operator new(size_t);
     void operator delete(void *, size_t);
@@ -277,7 +273,6 @@ class CacheFile {
     long length;
     long validdata; /* amount of successfully fetched data */
     int  refcnt;
-    ino_t inode;				/* for iopen() */
     char name[CACHEFILENAMELEN];		/* "xx/xx/xx/xx" */
     int numopens;
 
@@ -296,7 +291,7 @@ class CacheFile {
     void Validate();
     void Reset();
     int  Copy(CacheFile *destination);
-    int  Copy(char *destname, ino_t *ino = NULL, int recovering = 0);
+    int  Copy(char *destname, int recovering = 0);
 
     void IncRef() { refcnt++; } /* creation already does an implicit incref */
     int  DecRef();             /* returns refcnt, unlinks if refcnt becomes 0 */
@@ -307,7 +302,6 @@ class CacheFile {
     void SetValidData(long);
 
     char *Name()         { return(name); }
-    ino_t Inode()        { return(inode); }
     long Length()        { return(length); }
     long ValidData(void) { return(validdata); }
     int  IsPartial(void) { return(length != validdata); }
@@ -385,6 +379,7 @@ typedef enum {FROMHEAP, FROMFREELIST} fso_alloc_t; /* placement argument to oper
 typedef enum { HF_Fetch, HF_DontFetch } HoardFetchState;
 typedef enum { HA_Ask, HA_DontAsk } HoardAskState;
 
+class ClientModifyLog;
 class fsobj {
   friend void FSOInit();
   friend int FSO_PriorityFN(bsnode *, bsnode *);
@@ -428,7 +423,7 @@ class fsobj {
     AcRights AnyUser;				/* access control rights: any user */
     AcRights SpecificUser[CPSIZE];		/* access control rights: specific users */
     FsoFlags flags;				/* some of these are transient */
-    unsigned char VenusSHA[SHA_DIGEST_LENGTH]; /* if non-zero, the saved SHA of the file; used by lookaside code; */
+    unsigned char VenusSHA[SHA_DIGEST_LENGTH];	/* if non-zero, the saved SHA of the file; used by lookaside code; */
 
     /* Mount state. */
     MountStatus	mvstat;				/* { NORMAL, MOUNTPOINT, ROOT } */
@@ -659,7 +654,7 @@ class fsobj {
     int Sync(uid_t uid);
     void Release(int writep);
     int Close(int writep, uid_t uid);
-    int Access(long, int, uid_t);
+    int Access(int rights, int modes, uid_t);
     int Lookup(fsobj **, VenusFid *, char *, uid_t, int flags);
 // These are defined in lib-src/kernel-includes/coda.h
 // #define CLU_CASE_SENSITIVE	0x01
