@@ -456,7 +456,7 @@ void fsobj::Recover()
 		snprintf(spoolfile,MAXPATHLEN,"%s/%s-%u",SpoolDir,GetComp(),idx++);
 	    } while (::access(spoolfile, F_OK) == 0 || errno != ENOENT); 
 
-	    data.file->Copy(spoolfile, NULL, 1);
+	    data.file->Copy(spoolfile, 1);
 	    eprint("\t(lost file data backed up to %s)", spoolfile);
 	}
 	Recov_BeginTrans();
@@ -820,12 +820,11 @@ void fsobj::SetRcRights(int rights)
     if (vol->IsBackup() || IsFake())
 	return;
 
+    if (!HAVEALLDATA(this))
+	rights &= ~RC_DATA;
+
     LOG(100, ("fsobj::SetRcRights: (%s), rights = %d\n", FID_(&fid), rights));
 
-    /* There is a problem if the rights are set that we have valid data,
-     * but we actually don't have data yet. */
-    FSO_ASSERT(this, !(rights & RC_DATA) ||
-	             ((rights & RC_DATA) && HAVEALLDATA(this)));
     RcRights = rights;
 }
 
@@ -908,7 +907,7 @@ int fsobj::CheckAcRights(uid_t uid, long rights, int connected)
 
 exit_found:
     PutUser(&ue);
-    return (rights & allowed) ? 0 : EACCES;
+    return (!rights || (rights & allowed)) ? 0 : EACCES;
 }
 
 
@@ -1141,7 +1140,7 @@ int fsobj::TryToCover(VenusFid *inc_fid, uid_t uid)
 	Realm *r = vol->realm;
 	int n;
 
-	n = sscanf(data.symlink, "@%lx.%*x.%*x@%c", &vid.Volume, &tmp);
+	n = sscanf(data.symlink, "@%x.%*x.%*x@%c", &vid.Volume, &tmp);
 	if (n < 1) {
 	    print(logFile);
 	    CHOKE("fsobj::TryToCover: couldn't get volume id");
@@ -1194,7 +1193,7 @@ int fsobj::TryToCover(VenusFid *inc_fid, uid_t uid)
     root_fid.Realm = tvol->GetRealmId();
     root_fid.Volume = tvol->vid;
     if (IsFake()) {
-	if (sscanf(data.symlink, "@%*x.%lx.%lx", &root_fid.Vnode, &root_fid.Unique) != 2)
+	if (sscanf(data.symlink, "@%*x.%x.%x", &root_fid.Vnode, &root_fid.Unique) != 2)
 	    { print(logFile); CHOKE("fsobj::TryToCover: couldn't get <tvolid, tunique>"); }
     }
     else {
@@ -1449,9 +1448,9 @@ void fsobj::ComputePriority(int Force) {
     if (Force || priority == -1 || new_priority != priority) {
 	FSDB->Reorders++;		    /* transient value; punt set_range */
 
-	DisableReplacement();		    /* remove... */
-	priority = new_priority;	    /* update key... */
-	EnableReplacement();		    /* reinsert... */
+	DisableReplacement();		/* remove... */
+	priority = new_priority;    	/* update key... */
+	EnableReplacement();	 	/* reinsert... */
     }
 }
 
@@ -1475,7 +1474,7 @@ void fsobj::EnableReplacement() {
 	return;
 
     /* Are ALL conditions for replaceability met? */
-    if (DYING(this) || !HAVESTATUS(this) || DIRTY(this) ||
+    if (DYING(this) || !HAVESTATUS(this) || DIRTY(this) || IsLocalObj() ||
 	 READING(this) || WRITING(this) || (children && children->count() > 0) ||
 	 IsMtPt() || (IsSymLink() && hdb_bindings && hdb_bindings->count() > 0))
 	return;
@@ -1991,7 +1990,8 @@ int fsobj::Fakeify()
 	    if (p == &vol->fso_list) {
 		LOG(0, ("fsobj::Fakeify: %s, (%s), parent not found\n",
 			comp, FID_(&fid)));
-		return(ENOENT);
+		Matriculate();
+		return ENOENT;
 	    }
 	}
     }
@@ -2127,7 +2127,7 @@ int fsobj::Fakeify()
 	    stat.Length = 29 + strlen(realmname);
 	    data.symlink = (char *)rvmlib_rec_malloc(stat.Length+1);
 	    rvmlib_set_range(data.symlink, stat.Length+1);
-	    sprintf(data.symlink, "@%08lx.%08lx.%08lx@%s.",
+	    sprintf(data.symlink, "@%08x.%08x.%08x@%s.",
 		    LinkFid.Volume, LinkFid.Vnode, LinkFid.Unique, realmname);
 
 	    LOG(0, ("fsobj::Fakeify: making %s a symlink %s\n",
@@ -2208,7 +2208,7 @@ int fsobj::Fakeify()
 	stat.Length = 29 + strlen(realmname);
 	data.symlink = (char *)rvmlib_rec_malloc(stat.Length+1);
 	rvmlib_set_range(data.symlink, stat.Length+1);
-	sprintf(data.symlink, "@%08lx.%08lx.%08lx@%s.",
+	sprintf(data.symlink, "@%08x.%08x.%08x@%s.",
 		LinkFid.Volume, LinkFid.Vnode, LinkFid.Unique, realmname);
 
 	LOG(0, ("fsobj::Fakeify: making %s a symlink %s\n",
@@ -2252,6 +2252,7 @@ int fsobj::Fakeify()
     }
 
 done:
+    DisableReplacement();
     /* notify blocked threads that the fso is ready. */
     Matriculate();
     Recov_EndTrans(CMFP);
