@@ -581,7 +581,7 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 
     /* SHA value (not always used) */
     RPC2_BoundedBS mysha; 
-    mysha.SeqBody = VenusSHA;
+    mysha.SeqBody = (RPC2_Byte *)VenusSHA;
     mysha.MaxSeqLen = SHA_DIGEST_LENGTH;
     mysha.SeqLen = 0; 
 
@@ -948,7 +948,7 @@ int fsobj::GetAttr(uid_t uid, RPC2_BoundedBS *acl)
 
 	    if (LogLevel >= 10 && mysha.SeqLen == SHA_DIGEST_LENGTH) {
 		char printbuf[2*SHA_DIGEST_LENGTH+1];
-		ViceSHAtoHex(mysha.SeqBody, printbuf, sizeof(printbuf));
+		ViceSHAtoHex(VenusSHA, printbuf, sizeof(printbuf));
 		dprint("mysha(%d, %d) = %s\n.", mysha.MaxSeqLen, mysha.SeqLen,
 		       printbuf);
 	    }
@@ -1174,26 +1174,19 @@ int fsobj::GetACL(RPC2_BoundedBS *acl, uid_t uid)
 {
     LOG(10, ("fsobj::GetACL: (%s), uid = %d\n", GetComp(), uid));
 
-    if (!HOARDING(this) && !LOGGING(this)) {
-	FSO_ASSERT(this, EMULATING(this));
-
-	/* We don't cache ACLs! */
-	return(ETIMEDOUT);
-    }
-
     if (IsFake() || IsLocalObj()) {
 	/* Just read/lookup rights for System:AnyUser */
 	const char *fakeacl = "1\n0\nSystem:AnyUser\t9\n";
 	acl->SeqLen = strlen(fakeacl) + 1;
 	memcpy(acl->SeqBody, fakeacl, acl->SeqLen);
-	return(0);
+	return 0;
     }
 
     /* check if the object is FETCHABLE first! */
-    if (FETCHABLE(this))
-	return(GetAttr(uid, acl));
-    else 
-	return(ETIMEDOUT);
+    if (!FETCHABLE(this))
+	return ETIMEDOUT;
+
+    return GetAttr(uid, acl);
 }
 
 
