@@ -110,8 +110,8 @@ void RealmDB::GetDown(void)
 
 	if (!realm->refcount && !realm->rec_refcount) {
 	    Recov_BeginTrans();
-	    realm->GetRef();
-	    realm->PutRef();
+	    realm->Rec_GetRef();
+	    realm->Rec_PutRef();
 	    Recov_EndTrans(MAXFP);
 	}
     }
