@@ -465,7 +465,6 @@ void vproc::GetStamp(char *buf) {
 	case VPT_Worker:	t = 'W'; break;
 	case VPT_Mariner:	t = 'M'; break;
 	case VPT_CallBack:	t = 'C'; break;
-        case VPT_WriteBack:     t = 'w'; break;
 	case VPT_HDBDaemon:	t = 'H'; break;
 	case VPT_Reintegrator:	t = 'I'; break;
 	case VPT_Resolver:	t = 'R'; break;
@@ -648,15 +647,6 @@ void vproc::End_VFS(int *retryp) {
     if (VprocInterrupted())
 	{ u.u_error = EINTR; goto Exit; }
 
-    /* Cannot retry CODA_CLOSE operations! */
-    if (type == VPT_Worker) {
-	worker *w = (worker *)this;
-	if (w->opcode == CODA_CLOSE) {
-	    u.u_error = EINVAL;
-	    goto Exit;
-	}
-    }
-
     /* Caller should be prepared to retry! */
     if (!retryp)
 	{ if (u.u_error == ERETRY) u.u_error = EWOULDBLOCK; goto Exit; }
