@@ -52,7 +52,6 @@ extern "C" {
 
 /* from vicedep */
 #include <venusioctl.h>
-#include <writeback.h>
 /* from venus */
 #include "comm.h"
 #include "fso.h"
@@ -118,7 +117,7 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			/* always change ACLs.  Alternatively, we
                            could have venus cache the identity */
 			/* of administrators. */
-			/* u.u_error = f->Access((long)PRSFS_ADMINISTER, 0, u.u_uid); if (u.u_error) break; */
+			/* u.u_error = f->Access(PRSFS_ADMINISTER, C_A_F_OK, u.u_uid); if (u.u_error) break; */
 
 			/* Do the operation. */
 			RPC2_CountedBS acl;
@@ -145,7 +144,7 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
                            could have venus cache the identity */
 			/* of administrators. */
 /*
-			 u.u_error = f->Access((long)PRSFS_LOOKUP, 0, u.u_uid);
+			 u.u_error = f->Access(PRSFS_LOOKUP, C_A_F_OK, u.u_uid);
 			 if (u.u_error) break;
 */
 
@@ -243,7 +242,7 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			u.u_error = 0;
 
 			/* Verify that we have insert permission. */
-			u.u_error = f->Access((long)PRSFS_INSERT, 0, u.u_uid);
+			u.u_error = f->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 			if (u.u_error) { break; }
 
 			/*
@@ -310,7 +309,7 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
                         }
 
 			/* Verify that we have delete permission for the parent. */
-			u.u_error = f->Access((long)PRSFS_DELETE, 0, u.u_uid);
+			u.u_error = f->Access(PRSFS_DELETE, C_A_F_OK, u.u_uid);
 			if (u.u_error) {
                             FSDB->Put(&target_fso);
                             break;
@@ -364,7 +363,7 @@ void vproc::do_ioctl(VenusFid *fid, unsigned char nr, struct ViceIoctl *data)
 			    { u.u_error = ENOTDIR; FSDB->Put(&target_fso); break; }
 
 			/*Verify that we have read permission for it. */
-			u.u_error = target_fso->Access((long)PRSFS_LOOKUP, 0, u.u_uid);
+			u.u_error = target_fso->Access(PRSFS_LOOKUP, C_A_F_OK, u.u_uid);
 			if (u.u_error) { FSDB->Put(&target_fso); break; }
 
 			/* Retrieve the link contents from the cache. */
@@ -652,8 +651,9 @@ OI_FreeLocks:
 		    MOTD.SeqLen = 0;
 
 		    VolumeStateType conn_state;
-		    int             conflict;
-		    int             cml_count;
+		    unsigned int    age, hogtime;
+		    int             conflict, cml_count;
+		    uint64_t	    cml_bytes;
 		    int		    local_only = 0;
 		    if (data->in_size == sizeof(int) &&
 			*(int *)data->in == 1)
@@ -661,7 +661,9 @@ OI_FreeLocks:
 
 		    /* Retrieve the volume status from the server(s). */
 		    u.u_error = v->GetVolStat(&volstat, &Name, &conn_state,
+					      &age, &hogtime,
 					      &conflict, &cml_count,
+					      &cml_bytes,
 					      &OfflineMsg, &MOTD, u.u_uid,
 					      local_only);
 		    if (u.u_error) break;
@@ -675,7 +677,10 @@ OI_FreeLocks:
 			 sizeof(int) + /* conflict */
 			 sizeof(int) + /* cml_count */
 			 strlen(offlinemsg) + 1 + /* offlinemsg */
-			 strlen(motd) + 1) /* motd */
+			 strlen(motd) + 1 + /* motd */
+			 sizeof(unsigned int) + /* age */
+			 sizeof(unsigned int) + /* hogtime */
+			 sizeof(uint64_t))	/* cml_bytes */
 			 > VC_MAXDATASIZE ) {
 			LOG(0, ("vproc::do_ioctl: VIOCGETVOLSTAT: buffer is "
 				"not large enough to hold the message\n"));
@@ -688,18 +693,21 @@ OI_FreeLocks:
 						     be copied into */
 		    memcpy(cp, &volstat, sizeof(VolumeStatus));
 		    cp += sizeof(VolumeStatus);
-		    strcpy(cp, name);
-		    cp += strlen(name) + 1;
-		    memcpy (cp, &conn_state, sizeof(int));
-		    cp += sizeof(int);
-		    memcpy (cp, &conflict, sizeof(int));
-		    cp += sizeof(int);
-		    memcpy (cp, &cml_count, sizeof(int));
-		    cp += sizeof(int);
-		    strcpy(cp, offlinemsg);
-		    cp += strlen(offlinemsg) + 1;
-		    strcpy(cp, motd);
-		    cp += strlen(motd) + 1;
+		    strcpy(cp, name); cp += strlen(name) + 1;
+
+		    /* do we have to worry about alignment? */
+		    *(int32_t *)cp = (int32_t)conn_state; cp += sizeof(int32_t);
+		    *(int32_t *)cp = (int32_t)conflict;   cp += sizeof(int32_t);
+		    *(int32_t *)cp = (int32_t)cml_count;  cp += sizeof(int32_t);
+
+		    strcpy(cp, offlinemsg); cp += strlen(offlinemsg) + 1;
+		    strcpy(cp, motd); cp += strlen(motd) + 1;
+
+		    *(uint32_t *)cp = (uint32_t)age;     cp += sizeof(uint32_t);
+		    *(uint32_t *)cp = (uint32_t)hogtime; cp += sizeof(uint32_t);
+		    *(uint64_t *)cp = (uint64_t)cml_bytes;
+		    cp += sizeof(uint64_t);
+
 		    data->out_size = (cp - data->out);
 		    break;
 		    }
@@ -1002,7 +1010,6 @@ V_FreeLocks:
 	case _VIOC_TRUNCATELOG:
 	case _VIOC_DISCONNECT:
 	case _VIOC_RECONNECT:
-	case _VIOC_SLOW:
 	case _VIOC_STRONG:
 	case _VIOC_ADAPTIVE:
 	case _VIOC_LISTCACHE:
@@ -1404,18 +1411,6 @@ V_FreeLocks:
 		    break;
 		    }
 
-	        case _VIOC_SLOW:
-		    {
-		    if (data->in_size != (int)sizeof(unsigned))
-			{ u.u_error = EINVAL; break; }
-
-		    unsigned *speed = (unsigned *)data->in;
-
-		    u.u_error = FailSlow(speed);
-		    if (u.u_error < 0) u.u_error = EINVAL; /* fail returns -1 */
-		    break;
-		    }
-
 		/* cfs strong: Force strong connectivity to all servers */
 	        case _VIOC_STRONG:
 		    {
