@@ -166,8 +166,8 @@ FreeLocks:
 
 /* ***** Vnode Operations  ***** */
 
-void vproc::open(struct venus_cnode *cp, int flags) {
-
+void vproc::open(struct venus_cnode *cp, int flags)
+{
     LOG(1, ("vproc::open: fid = %s , flags = %x\n", 
 	    FID_(&cp->c_fid), flags));
 
@@ -196,9 +196,8 @@ void vproc::open(struct venus_cnode *cp, int flags) {
 
 	/* Verify that we have the necessary permission. */
 	if (readp) {
-	    long rights = f->IsFile() ? PRSFS_READ : PRSFS_LOOKUP;
-	    int modes = f->IsFile() ? C_A_R_OK : 0;
-	    u.u_error = f->Access(rights, modes, u.u_uid);
+	    int rights = f->IsFile() ? PRSFS_READ : PRSFS_LOOKUP;
+	    u.u_error = f->Access(rights, C_A_R_OK, u.u_uid);
 	    if (u.u_error) goto FreeLocks;
 	}
 	if (writep || truncp) {
@@ -211,9 +210,8 @@ void vproc::open(struct venus_cnode *cp, int flags) {
 	         Otherwise, either write or insert suffices (to support
                    insert only directories). 
 	    */
-	    long rights = (truncp ?  (long)PRSFS_WRITE :
-				     (long)(PRSFS_WRITE | PRSFS_INSERT));
-	    int modes = (createp ? C_A_C_OK : C_A_W_OK);
+	    int rights = truncp ? PRSFS_WRITE : (PRSFS_WRITE | PRSFS_INSERT);
+	    int modes = createp ? C_A_C_OK : C_A_W_OK;
 	    u.u_error = f->Access(rights, modes, u.u_uid);
 	    if (u.u_error) goto FreeLocks;
 	}
@@ -247,34 +245,31 @@ void vproc::close(struct venus_cnode *cp, int flags)
 
     fsobj *f = 0;
 
-    for (;;) {
-	Begin_VFS(&cp->c_fid, CODA_CLOSE, writep ? VM_MUTATING : VM_OBSERVING);
-	if (u.u_error) break;
+    Begin_VFS(&cp->c_fid, CODA_CLOSE, writep ? VM_MUTATING : VM_OBSERVING);
+    if (u.u_error) goto Exit;
 
-	/* Get the object. */
-        /* We used to fetch the DATA too.  However, this creates problems
-         * if you are in the DYING state and you have an active reference to
-         * the file (since you cannot fetch and you cannot garbage collect).
-         * We're reasonably confident that closing an object without having
-         * the DATA causes no problems; however, we'll leave a zero-level 
-         * log statement in as evidence to the contrary... (mre:6/14/94) 
-         */
-        u.u_error = FSDB->Get(&f, &cp->c_fid, u.u_uid, RC_STATUS);
-        if (u.u_error) goto FreeLocks;
+    /* Get the object. */
+    /* We used to fetch the DATA too.  However, this creates problems
+     * if you are in the DYING state and you have an active reference to
+     * the file (since you cannot fetch and you cannot garbage collect).
+     * We're reasonably confident that closing an object without having
+     * the DATA causes no problems; however, we'll leave a zero-level 
+     * log statement in as evidence to the contrary... (mre:6/14/94) 
+     */
+    u.u_error = FSDB->Get(&f, &cp->c_fid, u.u_uid, RC_STATUS);
+    if (u.u_error) goto FreeLocks;
 
-        if (!DYING(f) && !HAVEALLDATA(f)) 
-          LOG(0, ("vproc::close: Don't have DATA and not DYING! (fid = %s, flags = %x)\n", FID_(&cp->c_fid), flags));
+    if (!DYING(f) && !HAVEALLDATA(f)) 
+	LOG(0, ("vproc::close: Don't have DATA and not DYING! (fid = %s, flags = %x)\n", FID_(&cp->c_fid), flags));
 
-	/* Do the operation. */
-	u.u_error = f->Close(writep, u.u_uid /*, not_written */);
+    /* Do the operation. */
+    u.u_error = f->Close(writep, u.u_uid /*, not_written */);
 
 FreeLocks:
-	FSDB->Put(&f);
-	int retry_call = 0;
-	End_VFS(&retry_call);
-	if (!retry_call) break;
-    }
+    FSDB->Put(&f);
+    End_VFS(NULL);
 
+Exit:
     if (u.u_error == EINCONS) {
 	u.u_error = EINVAL;	    /* XXX -JJK */
 	k_Purge(&cp->c_fid, 1);
@@ -446,7 +441,7 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
 		if (f->stat.Owner != (uid_t)vap->va_uid)
 		    { u.u_error = EACCES; goto FreeLocks; }
 #endif
-		u.u_error = f->Access((long)PRSFS_ADMINISTER, 0, u.u_uid);
+		u.u_error = f->Access(PRSFS_ADMINISTER, C_A_F_OK, u.u_uid);
 		if (u.u_error) goto FreeLocks;
 	    }
 
@@ -457,14 +452,14 @@ void vproc::setattr(struct venus_cnode *cp, struct coda_vattr *vap) {
 		    goto FreeLocks; 
 		}
 
-		u.u_error = f->Access((long)PRSFS_WRITE, C_A_W_OK, u.u_uid);
+		u.u_error = f->Access(PRSFS_WRITE, C_A_W_OK, u.u_uid);
 		if (u.u_error) 
 		    goto FreeLocks;
 	    }
 
 	    /* utimes */
 	    if (vap->va_mtime.tv_sec != VA_IGNORE_TIME1) {
-		    u.u_error = f->Access((long)PRSFS_WRITE, 0, u.u_uid);
+		    u.u_error = f->Access(PRSFS_WRITE, C_A_F_OK, u.u_uid);
 		    if (u.u_error) goto FreeLocks;
 	    }
 	}
@@ -494,27 +489,27 @@ void vproc::access(struct venus_cnode *cp, int mode)
     LOG(1, ("vproc::access: fid = %s, mode = %#o\n", FID_(&cp->c_fid), mode));
 
     /* Translation of Unix mode bits to AFS protection classes. */
-    static long DirAccessMap[8] = {
-	0,
-	PRSFS_LOOKUP,
-	PRSFS_INSERT | PRSFS_DELETE,
-	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE,
-	PRSFS_LOOKUP,
-	PRSFS_LOOKUP,
-	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE,
-	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE
+    static int DirAccessMap[8] = {
+/*---*/	0,
+/*--x*/	PRSFS_LOOKUP,
+/*-w-*/	PRSFS_INSERT | PRSFS_DELETE,
+/*-wx*/	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE,
+/*r--*/	PRSFS_LOOKUP,
+/*r-x*/	PRSFS_LOOKUP,
+/*rw-*/	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE,
+/*rwx*/	PRSFS_LOOKUP | PRSFS_INSERT | PRSFS_DELETE
     };
-    static long FileAccessMap[8] = {
-	0,
-	PRSFS_READ,
-	PRSFS_WRITE,
-	PRSFS_READ | PRSFS_WRITE,
-	PRSFS_READ,
-	PRSFS_READ,
-	PRSFS_READ | PRSFS_WRITE,
-	PRSFS_READ | PRSFS_WRITE
+    static int FileAccessMap[8] = {
+/*---*/	0,
+/*--x*/	PRSFS_READ,
+/*-w-*/	PRSFS_WRITE,
+/*-wx*/	PRSFS_READ | PRSFS_WRITE,
+/*r--*/	PRSFS_READ,
+/*r-x*/	PRSFS_READ,
+/*rw-*/	PRSFS_READ | PRSFS_WRITE,
+/*rwx*/	PRSFS_READ | PRSFS_WRITE
     };
-    long rights = 0;
+    int rights = 0;
     int modes = 0;
 
     fsobj *f = 0;
@@ -527,10 +522,11 @@ void vproc::access(struct venus_cnode *cp, int mode)
 	u.u_error = FSDB->Get(&f, &cp->c_fid, u.u_uid, RC_STATUS);
 	if (u.u_error) goto FreeLocks;
 
-	modes = mode & (OWNERBITS >> 6);
-	rights = f->IsDir()
-	  ? DirAccessMap[modes]
-	  : FileAccessMap[modes];
+	modes = C_A_F_OK;
+	if (mode & R_OK) modes |= C_A_R_OK;
+	if (mode & W_OK) modes |= C_A_W_OK;
+	if (mode & X_OK) modes |= C_A_X_OK;
+	rights = f->IsDir() ? DirAccessMap[modes] : FileAccessMap[modes];
 	u.u_error = f->Access(rights, modes, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
@@ -679,11 +675,11 @@ void vproc::create(struct venus_cnode *dcp, char *name, struct coda_vattr *vap,
 
 	    /* Verify that we have the necessary permissions. */
 	    if (readp) {
-		u.u_error = target_fso->Access((long)PRSFS_READ, C_A_R_OK, u.u_uid);
+		u.u_error = target_fso->Access(PRSFS_READ, C_A_R_OK, u.u_uid);
 		if (u.u_error) goto FreeLocks;
 	    }
 	    if (writep || truncp) {
-		u.u_error = target_fso->Access((long)PRSFS_WRITE, C_A_W_OK, u.u_uid);
+		u.u_error = target_fso->Access(PRSFS_WRITE, C_A_W_OK, u.u_uid);
 		if (u.u_error) goto FreeLocks;
 	    }
 
@@ -710,7 +706,7 @@ void vproc::create(struct venus_cnode *dcp, char *name, struct coda_vattr *vap,
 	    u.u_error = 0;
 
 	    /* Verify that we have create permission. */
-	    u.u_error = parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
+	    u.u_error = parent_fso->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 	    if (u.u_error) goto FreeLocks;
 
 	    /* Do the create. */
@@ -724,8 +720,6 @@ void vproc::create(struct venus_cnode *dcp, char *name, struct coda_vattr *vap,
 	/* Set OUT parameters. */
 	target_fso->GetVattr(vap);
 	MAKE_CNODE2(*cp, target_fso->fid, C_VREG);
-	cp->c_device = FSDB->device;
-	cp->c_inode = target_fso->data.file->Inode();
 
 FreeLocks:
 	FSDB->Put(&parent_fso);
@@ -775,7 +769,7 @@ void vproc::remove(struct venus_cnode *dcp, char *name)
 	    { u.u_error = EISDIR; goto FreeLocks; }
 
 	/* Verify that we have delete permission for the parent. */
-	u.u_error = parent_fso->Access((long)PRSFS_DELETE, 0, u.u_uid);
+	u.u_error = parent_fso->Access(PRSFS_DELETE, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Do the remove. */
@@ -865,11 +859,11 @@ void vproc::link(struct venus_cnode *scp, struct venus_cnode *dcp,
         }
 
 	/* Verify that we have insert permission on the target parent. */
-	u.u_error = parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
+	u.u_error = parent_fso->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Verify that we have write permission on the source. */
-	u.u_error = source_fso->Access((long)PRSFS_WRITE, 0, u.u_uid);
+	u.u_error = source_fso->Access(PRSFS_WRITE, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Do the operation. */
@@ -947,10 +941,10 @@ void vproc::rename(struct venus_cnode *spcp, char *name,
 	/* Verify that we have the necessary permissions in the parent(s). */
 	{
 	    fsobj *f = (SameParent ? t_parent_fso : s_parent_fso);
-	    u.u_error = f->Access((long)PRSFS_DELETE, 0, u.u_uid);
+	    u.u_error = f->Access(PRSFS_DELETE, C_A_F_OK, u.u_uid);
 	    if (u.u_error) goto FreeLocks;
 	}
-	u.u_error = t_parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
+	u.u_error = t_parent_fso->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Acquire the source and target (if it exists). */
@@ -1025,7 +1019,7 @@ void vproc::rename(struct venus_cnode *spcp, char *name,
 	if (TargetExists) {
 	    /* Verify that we have delete permission in the target parent. */
 	    if (!SameParent) {
-		u.u_error = t_parent_fso->Access((long)PRSFS_DELETE, 0, u.u_uid);
+		u.u_error = t_parent_fso->Access(PRSFS_DELETE, C_A_F_OK, u.u_uid);
 		if (u.u_error) goto FreeLocks;
 	    }
 
@@ -1144,7 +1138,7 @@ void vproc::mkdir(struct venus_cnode *dcp, char *name,
 	u.u_error = 0;
 
 	/* Verify that we have insert permission. */
-	u.u_error = parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
+	u.u_error = parent_fso->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Do the operation. */
@@ -1219,7 +1213,7 @@ void vproc::rmdir(struct venus_cnode *dcp, char *name)
 	    { u.u_error = ENOTEMPTY; goto FreeLocks; }
 
 	/* Verify that we have delete permission for the parent. */
-	u.u_error = parent_fso->Access((long)PRSFS_DELETE, 0, u.u_uid);
+	u.u_error = parent_fso->Access(PRSFS_DELETE, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Do the operation. */
@@ -1275,7 +1269,7 @@ void vproc::symlink(struct venus_cnode *dcp, char *contents,
 	u.u_error = 0;
 
 	/* Verify that we have insert permission. */
-	u.u_error = parent_fso->Access((long)PRSFS_INSERT, 0, u.u_uid);
+	u.u_error = parent_fso->Access(PRSFS_INSERT, C_A_F_OK, u.u_uid);
 	if (u.u_error) goto FreeLocks;
 
 	/* Do the operation. */
@@ -1330,7 +1324,7 @@ void vproc::readlink(struct venus_cnode *cp, struct coda_string *string)
 
 	/* Verify that we have read permission for it. */
 /*
-	 u.u_error = f->Access((long)PRSFS_LOOKUP, 0, u.u_uid);
+	 u.u_error = f->Access(PRSFS_LOOKUP, C_A_F_OK, u.u_uid);
 	 if (u.u_error)
 	     { if (u.u_error == EINCONS) u.u_error = ENOENT; goto FreeLocks; }
 */
@@ -1355,7 +1349,7 @@ FreeLocks:
 	/* Make a "fake" name for the inconsistent object. */
 	Realm *realm = REALMDB->GetRealm(cp->c_fid.Realm);
 	CODA_ASSERT(realm);
-	len = snprintf(buf, len, "@%08lx.%08lx.%08lx@%s", cp->c_fid.Volume,
+	len = snprintf(buf, len, "@%08x.%08x.%08x@%s", cp->c_fid.Volume,
 		       cp->c_fid.Vnode, cp->c_fid.Unique, realm->Name());
 	string->cs_len = 28 + strlen(realm->Name());
 	realm->PutRef();
