@@ -39,11 +39,14 @@ vsgent::vsgent(struct in_addr Hosts[VSG_MEMBERS], RealmId id)
 
     realmid = id;
     nhosts = 0;
+    max_vsg = 0;
     for (i = 0; i < VSG_MEMBERS; i++) {
         hosts[i] = Hosts[i];
 
-        if (Hosts[i].s_addr)
+        if (Hosts[i].s_addr) {
             nhosts++;
+	    max_vsg = i+1;
+	}
     }
 
     list_head_init(&mgrpents);
@@ -85,7 +88,7 @@ try_again:
 
     list_for_each(p, mgrpents) {
         *m = list_entry_plusplus(p, mgrpent, vsghandle);
-        if (uid != ALL_UIDS && uid != (*m)->uid)
+        if (uid != (*m)->uid)
             continue;
 
         count++;
@@ -139,7 +142,8 @@ got_mgrp:
         goto exit;
 
     /* Choose whether to multicast or not. XXX probably broken --JH */
-    (*m)->rocc.MIp = (UseMulticast) ? &(*m)->McastInfo : 0;
+    //(*m)->rocc.MIp = (UseMulticast) ? &(*m)->McastInfo : 0;
+    (*m)->rocc.MIp = 0;
     
 /*--- We should have a usable mgrp now */
 
@@ -149,6 +153,9 @@ exit:
         *m = NULL;
     }
 
+    if (code == ERETRY)
+	goto try_again;
+
     return(code);
 }
 
