@@ -79,7 +79,7 @@ extern void VAdjustDiskUsage(Error *, Volume *, int);
 extern int  VCheckVLDB();
 extern void VPrintCacheStats(FILE * =stdout);
 extern void ViceUpdateDB();
-extern void SwapLog();
+extern void SwapLog(int ign);
 extern void SwapMalloc();
 extern void ViceTerminate();
 
