@@ -57,7 +57,6 @@ extern "C" {
 #include <vice.h>
 #include <venusioctl.h>
 #include <prs.h>
-#include <writeback.h>
 #include <codaconf.h>
 #include <inconsist.h>
 #include <coda_config.h>
@@ -140,7 +139,6 @@ static void RmMount(int, char**, int);
 static void SetACL(int, char**, int);
 static void SetQuota(int, char **, int);
 static void SetVolume(int, char **, int);
-static void Slow(int, char **, int);
 static void Strong(int, char**, int);
 static void TruncateLog(int, char **, int);
 static void UnloadKernel(int, char **, int);
@@ -389,24 +387,6 @@ struct command cmdarray[] =
 	    "Force modifications in a disconnected volume to the server",
 	    NULL
 	}
-#if 0 /* disabled these until the compression/filcon stuff works --JH */
-        ,
-	{"slow", NULL, Slow, 
-            "cfs slow <speed (bps)>",
-            "Set network speed",
-            NULL
-        },
-        {"compress", NULL, Compress, 
-            "cfs compress <file> [<file> <file> ...]",
-            "Compress cached files",
-            NULL
-        },
-        {"uncompress", NULL, Uncompress, 
-            "cfs uncompress <file> [<file> <file> ...]",
-            "Uncompress cached files",
-            NULL
-        }
-#endif
     };
 
 /* Number of commands in cmdarray */
@@ -635,8 +615,8 @@ static int dirincoda(char *path)
     if (rc < 0) return(0);
     
     /* Now find out where we really are */
-    rc = (int)getcwd(buf, MAXPATHLEN);
-    if (rc == 0) return(0);
+    if (getcwd(buf, MAXPATHLEN) == NULL)
+	return(0);
     
     /* Are we in Kansas, Toto? */
     vio.in = 0;
@@ -684,30 +664,6 @@ static void ClearPriorities(int argc, char *argv[], int opslot)
     if (rc < 0) { PERROR("  VIOC_CLEARPRIORITIES"); exit(-1); }
 }
 
-#ifdef UNUSED
-static void Compress(int argc, char *argv[], int opslot)
-{
-    int i, rc; 
-    struct ViceIoctl vio;
-
-    if (argc < 3) {
-        printf("Usage: %s\n", cmdarray[opslot].usetxt);
-        exit(-1);
-    }
-
-    for (i = 2; i < argc; i++) {
-        if (argc > 3) printf("  %s", argv[i]);
-        vio.in = 0;
-        vio.in_size = 0;
-        vio.out = 0;
-        vio.out_size = 0;
-        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_COMPRESS), &vio, 1);
-        if (rc < 0) { PERROR("VIOC_COMPRESS"); continue; }
-        if (argc > 3) printf("\n");
-    }
-}
-#endif
-
 static void Redir (int argc, char *argv[], int opslot)
 {
     int rc;
@@ -1274,13 +1230,8 @@ static void GetFid(int argc, char *argv[], int opslot)
 	sprintf(buf, "%x.%x.%x@%s", (unsigned int)fid.Volume,
 		(unsigned int)fid.Vnode, (unsigned int)fid.Unique, realmname);
         printf("FID = %-20s  ", buf);
-        sprintf(buf, "[%ld %ld %ld %ld %ld %ld %ld %ld]",
-               vv.Versions.Site0, vv.Versions.Site1, vv.Versions.Site2,
-               vv.Versions.Site3, vv.Versions.Site4, vv.Versions.Site5,
-               vv.Versions.Site6, vv.Versions.Site7);
-        printf("VV = %-24s  ", buf);
-        printf("STOREID = %lx.%lx  FLAGS = 0x%lx\n", vv.StoreId.Host, 
-                vv.StoreId.Uniquifier, vv.Flags);
+	SPrintVV(buf, sizeof(buf), &vv);
+        printf("VV = %-24s\n", buf);
     }
 }
 
@@ -1304,7 +1255,7 @@ static void GetPFid(int argc, char *argv[], int opslot)
         if (argc > 3) printf("  %*s  ", w, argv[i]); /* echo input if more than one fid */
         /* Validate next fid */
 	char tmp;
-        if (sscanf(argv[i], "%lx.%lx.%lx@%c", &fid.Volume, &fid.Vnode, &fid.Unique, &tmp) != 4)
+        if (sscanf(argv[i], "%x.%x.%x@%c", &fid.Volume, &fid.Vnode, &fid.Unique, &tmp) != 4)
 	{
             printf("Malformed fid: should look like %%x.%%x.%%x@<realm>\n");
             continue;
@@ -1394,7 +1345,7 @@ static void GetPath(int argc, char *argv[], int opslot)
         if (argc > 3) printf("  %*s  ", w, argv[i]); /* echo input if more than one fid */
         /* Validate next fid */
 	char tmp;
-        if (sscanf(argv[i], "%lx.%lx.%lx@%c", &fid.Volume, &fid.Vnode, &fid.Unique, &tmp) != 4)
+        if (sscanf(argv[i], "%x.%x.%x@%c", &fid.Volume, &fid.Vnode, &fid.Unique, &tmp) != 4)
 	{
             printf("Malformed fid: should look like %%x.%%x.%%x@<realm>\n");
             continue;
@@ -1809,8 +1760,9 @@ static void ListVolume(int argc, char *argv[], int opslot)
     VolumeStatus *vs;
     char *volname, *omsg, *motd;
     VolumeStateType conn_state;
-    int conflict;
-    int cml_count;
+    int conflict, cml_count;
+    unsigned int age, hogtime;
+    uint64_t cml_bytes;
     char *ptr;
     int local_only = 0;
 
@@ -1838,47 +1790,54 @@ static void ListVolume(int argc, char *argv[], int opslot)
         
         /* Get pointers to output fields */
 	/* Format is (status, name, conn_state, conflict,
-	   cml_count, offlinemsg, motd) */
+	   cml_count, offlinemsg, motd, age, hogtime, cml_bytes) */
 	ptr = piobuf;		/* invariant: ptr always point to next obj
 				   to be read */
         vs = (VolumeStatus *)ptr;
 	ptr += sizeof(VolumeStatus);
-        volname = ptr;
-	ptr += strlen(volname)+1;
-	memcpy ((void *)&conn_state, (void *)ptr, sizeof(int));
-	ptr += sizeof(int);
-	memcpy ((void *)&conflict, (void *)ptr, sizeof(int));
-	ptr += sizeof(int);
-	memcpy ((void *)&cml_count, (void *)ptr, sizeof(int));
-	ptr += sizeof(int);
-        omsg = ptr;
-	ptr += strlen(omsg)+1;
-        motd = ptr;
-	ptr += strlen(motd)+1;
+        volname = ptr; ptr += strlen(volname)+1;
+
+	conn_state = (VolumeStateType)*(int32_t *)ptr;
+	ptr += sizeof(int32_t);
+	conflict = *(int32_t *)ptr;
+	ptr += sizeof(int32_t);
+	cml_count = *(int32_t *)ptr;
+	ptr += sizeof(int32_t);
+
+	omsg = ptr; ptr += strlen(omsg)+1;
+	motd = ptr; ptr += strlen(motd)+1;
+
+	age = *(uint32_t *)ptr;
+	ptr += sizeof(uint32_t);
+	hogtime	= *(uint32_t *)ptr;
+	ptr += sizeof(uint32_t);
+	cml_bytes = *(uint64_t *)ptr;
+	ptr += sizeof(uint64_t);
 
         /* Print output fields */
         if (argc > 3) printf("  %s:\n", argv[i]);  /* print directory name if more than one */
-        printf("  Status of volume 0x%lx (%lu) named \"%s\"\n",
+        printf("  Status of volume %08x (%u) named \"%s\"\n",
             vs->Vid, vs->Vid, volname);
         if (*omsg) printf("  Offline message is \"%s\"\n", omsg);
         if (*motd) printf("  Message of the day is \"%s\"\n", motd);
         printf("  Volume type is %s\n", xlate_vvtype(vs->Type));
 	printf("  Connection State is %s\n", print_conn_state(conn_state));
+	printf("  Reintegration age: %u sec, hogtime %.3f sec\n",
+	       age, hogtime / 1000.0);
 	/* info not avail if disconnected, or if we did a local query */
 	if (conn_state!=Emulating && local_only == 0) {
-	    printf("  Minimum quota is %lu,", vs->MinQuota);
+	    printf("  Minimum quota is %u,", vs->MinQuota);
 	    if (vs->MaxQuota > 0)
-		printf(" maximum quota is %lu\n", vs->MaxQuota);
+		printf(" maximum quota is %u\n", vs->MaxQuota);
 	    else printf(" maximum quota is unlimited\n");
-	    printf("  Current blocks used are %lu\n", vs->BlocksInUse);
-	    printf("  The partition has %lu blocks available out of %lu\n",
+	    printf("  Current blocks used are %u\n", vs->BlocksInUse);
+	    printf("  The partition has %u blocks available out of %u\n",
 		   vs->PartBlocksAvail, vs->PartMaxBlocks);
 	}
 	if (conflict)
 	    printf("  *** There are pending conflicts in this volume ***\n");
 	if (conn_state == Logging || conn_state == Emulating)
-	    printf("  There are %d CML entries pending for reintegration\n",
-		   cml_count);
+	    printf("  There are %d CML entries pending for reintegration (%llu bytes)\n", cml_count, cml_bytes);
         printf("\n");
         }
 
@@ -2359,10 +2318,10 @@ static void SetQuota    (int argc, char *argv[], int opslot)
         
         /* Get pointers to output fields */
         vs = (VolumeStatus *)piobuf;
-        printf("maximum quota is %lu\n", vs->MaxQuota);
+        printf("maximum quota is %u\n", vs->MaxQuota);
 
         vs->MaxQuota = atoi(argv[i+1]);
-        printf("New value of vs->MaxQuota will be set to %lu\n", vs->MaxQuota);
+        printf("New value of vs->MaxQuota will be set to %u\n", vs->MaxQuota);
 
         vio.in_size  = CFS_PIOBUFSIZE;
         vio.in       = piobuf;
@@ -2374,28 +2333,6 @@ static void SetQuota    (int argc, char *argv[], int opslot)
     }
 }
 
-#ifdef UNUSED
-static void Slow(int argc, char *argv[], int opslot) 
-{
-    int rc;
-    struct ViceIoctl vio;
-    unsigned speed;
-
-    if (argc < 3) {
-	printf("Usage: %s\n", cmdarray[opslot].usetxt);
-	exit(-1);
-    }
-
-    speed = atoi(argv[2]);
-    vio.in = (char *)&speed;
-    vio.in_size = (int) sizeof(speed);
-    vio.out = 0;
-    vio.out_size = 0;
-    rc = pioctl(mountpoint, _VICEIOCTL(_VIOC_SLOW), &vio, 1);
-    if (rc < 0){ PERROR("VIOC_SLOW"); exit(-1);}    
-}
-#endif
-
 static void Strong(int argc, char *argv[], int opslot) 
 {
     int rc;
@@ -2451,31 +2388,6 @@ static void TruncateLog(int argc, char *argv[], int opslot)
 }
 
 
-#ifdef UNUSED
-static void Uncompress(int argc, char *argv[], int opslot)
-{
-    int i, rc; 
-    struct ViceIoctl vio;
-
-    if (argc < 3) {
-        printf("Usage: %s\n", cmdarray[opslot].usetxt);
-        exit(-1);
-    }
-
-    for (i = 2; i < argc; i++)
-    {
-        if (argc > 3) printf("  %s", argv[i]);
-        vio.in = 0;
-        vio.in_size = 0;
-        vio.out = 0;
-        vio.out_size = 0;
-        rc = pioctl(argv[i], _VICEIOCTL(_VIOC_UNCOMPRESS), &vio, 1);
-        if (rc < 0) { PERROR("  VIOC_UNCOMPRESS"); continue; }
-        if (argc > 3) printf("\n");
-    }
-}
-#endif
-
 static void UnloadKernel(int argc, char *argv[], int opslot)
 {
     struct ViceIoctl vio;
