@@ -17,6 +17,8 @@ listed in the file CREDITS.
 #*/
 
 #include <sys/param.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -68,6 +70,9 @@ static void do_rewrite(const char *conffile, int argc, char **argv)
     inf = fopen(conffile, "r");
     FAILIF(!inf, "Failed to open '%s' for reading\n", conffile);
 
+    /* Set umask to 022 so that the newly created file uses 0644 */
+    umask(022);
+
     /* find the last line that contains a (possibly commented) reference to our
      * variable, create a backup copy at the same time */
     snprintf(tmpname, MAXPATHLEN, "%s.bak", conffile);
@@ -150,7 +155,8 @@ static void copy_template(char *confbase)
 
 int main(int argc, char **argv)
 {
-    char *conffile, *val;
+    char *conffile, *val, *p;
+    int i, len;
     FAILIF(argc < 2, "Usage: %s <conffile> [<variable> [<value>]]\n", argv[0]);
 
     conffile = codaconf_file(argv[1]);
@@ -174,9 +180,10 @@ int main(int argc, char **argv)
 	FAILIF(!conffile, "Failed to copy template file to '%s'\n", argv[1]);
     }
 
+    codaconf_init_one(conffile);
+    val = codaconf_lookup(argv[2], NULL);
+
     if (argc < 4) {
-	codaconf_init_one(conffile);
-	val = codaconf_lookup(argv[2], NULL);
 	FAILIF(!val, "Variable '%s' not found in '%s'\n", argv[2], conffile);
 
 	fprintf(stdout, "%s\n", val);
@@ -184,6 +191,21 @@ int main(int argc, char **argv)
     }
 
     /* argc >= 4 */
+    /* check if this value was already set */
+    if (val) {
+	p = val;
+	for (i = 3; i <= argc; i++) {
+	    len = strlen(argv[i]);
+	    if (strncmp(argv[i], p, len) != 0)
+		break;
+	    p = p + len;
+	    if (*p != ' ') break;
+	    p++;
+	}
+	if (i == argc-1 && *p == '\0')
+	    exit(0);
+    }
+
     do_rewrite(conffile, argc, argv);
 
     exit(0);
