@@ -168,7 +168,6 @@ EOF
     if [ x${pkg} = xclient ]
     then
 	cat >> ${dst} << EOF
-sbin/au
 sbin/sidekick
 sbin/codaconfedit
 sbin/coda-setup-ports
@@ -177,6 +176,7 @@ sbin/venus
 sbin/venus-setup
 sbin/volmunge
 sbin/vutil
+bin/au
 bin/cfs
 bin/clog
 bin/cmon
@@ -194,6 +194,7 @@ bin/coda_replay
 bin/spy
 bin/xaskuser
 bin/xfrepair
+man/man1/au.1
 man/man1/cfs.1
 man/man1/clog.1
 man/man1/cmon.1
@@ -204,8 +205,9 @@ man/man1/cunlog.1
 man/man1/hoard.1
 man/man1/repair.1
 man/man1/spy.1
-man/man8/au.8
 man/man8/venus.8
+man/man8/venus-setup.8
+man/man8/volmunge.8
 etc/coda/realms
 etc/coda/venus.conf.ex
 etc/coda/sidekick.intr.ex
@@ -253,11 +255,29 @@ sbin/vice-setup-scm
 sbin/vice-setup-srvdir
 sbin/vice-setup-user
 sbin/volutil
+man/man5/backuplogs.5
+man/man5/dumpfile.5
+man/man5/dumplist.5
 man/man5/passwd.coda.5
+man/man5/maxgroupid.5
 man/man5/vicetab.5
+man/man5/volumelist.5
+man/man5/vrdb.5
 man/man8/auth2.8
+man/man8/backup.8
+man/man8/bldvldb.sh.8
+man/man8/createvol_rep.8
 man/man8/initpw.8
+man/man8/merge.8
 man/man8/pdbtool.8
+man/man8/purgevol_rep.8
+man/man8/readdump.8
+man/man8/startserver.8
+man/man8/updateclnt.8
+man/man8/updatesrv.8
+man/man8/vice-setup.8
+man/man8/volutil.8
+man/man8/vutil.8
 etc/coda/server.conf.ex
 etc/rc.d/rc.vice
 EOF
